@@ -1,8 +1,7 @@
-gem 'minitest'  # minitest in 1.9 stdlib is crufty
 require 'minitest/autorun'
 require 'mime'
 
-Encoding.default_external = 'ASCII-8BIT'  # may be able to remove in 2.0
+Encoding.default_external = 'ASCII-8BIT'
 
 
 class MIMETest < Minitest::Test
@@ -319,6 +318,29 @@ EOF
     assert_equal sender, msg.sender
   end
 
+  # Related type parameter: https://tools.ietf.org/html/rfc2387#section-3.1
+  def test_related_message_inherits_type_from_root
+    msg = MIME::Multipart::Related.new
+    refute_includes(msg.type, 'type')
+    msg.add(MIME::Text.new('body', 'plain'))        # Root object (first entity)
+    assert_includes(msg.type, 'type=text/plain')    # sets the related msg type.
+    msg.add(MIME::Text.new('body', 'html'))         # Additional entities have
+    refute_includes(msg.type, 'type=text/html')     # no effect on msg type.
+    assert_includes(msg.type, 'type=text/plain')
+  end
+
+  def test_related_message_inherits_parameterized_type_from_root
+    msg = MIME::Multipart::Related.new
+    refute_includes(msg.type, 'type')
+
+    root = MIME::Text.new('a message', 'plain', 'charset' => 'us-ascii')
+    assert_equal(root.type, 'text/plain; charset=us-ascii')
+
+    msg.add(root)
+    assert_includes(msg.type, 'type=text/plain')    # Inherits root mime type,
+    refute_includes(msg.type, 'charset=us-ascii')   # but params are omitted.
+  end
+
   def test_rfc2822_date_format
     msg = MIME::Mail.new
     assert_kind_of(Time, msg.date)
